import { defineStore } from "pinia";
import { useStorage } from "@vueuse/core";
import type { AuthenticatedUser } from "@/js/contexts/auth/models/AuthenticatedUser";

export const useAuthStore = defineStore("auth", () => {
  const isAuthenticated = useStorage<boolean>("auth.authenticated", false, undefined, { writeDefaults: false });
  const authenticatedUser = ref<AuthenticatedUser>();

  const setAuthenticatedUser = (user: AuthenticatedUser | null = null) => {
    isAuthenticated.value = !!user;
    authenticatedUser.value = user ?? undefined;
  };

  return {
    isAuthenticated,
    authenticatedUser,
    setAuthenticatedUser,
  };
});
